@@ -39,7 +39,7 @@ class FOPPDFConverter(object):
             output_filename = newTempfile(suffix='.pdf')
 
         if sys.platform == 'win32':
-            cmd = '%s\\fop.exe -fo "%s" -pdf "%s"' % (fop_home, fo_filename, output_filename)
+            cmd = '%s\\fop.bat -fo "%s" -pdf "%s"' % (fop_home, fo_filename, output_filename)
         else:
             cmd = '"%s/fop" -fo "%s" -pdf "%s"' % (fop_home, fo_filename, output_filename)
 
