@@ -91,10 +91,17 @@ class HTML2FOConverter(object):
 
         E = parse(fo_filename)
 
+        ids_seen = list()
         for node in E.getiterator():
-
             get = node.attrib.get
-            
+
+            # ensure that ID attributes are unique
+            node_id = get('id')
+            if node_id is not None:
+                if node_id in ids_seen:
+                    del node.attrib['id']
+                ids_seen.append(node_id)
+
             for k, v in (('footnote', 'reset'), 
                          ('unicode-bidi', 'embed'), 
                          ('writing-mode', 'lr-tb'), 
